@@ -5,6 +5,7 @@ from polygon import rest_connect
 import json
 import typer
 import simplejson
+import traceback
 class PolygonShell(cmd.Cmd):
     intro = 'Welcome to the Polygon Query shell.   Type help or ? to list commands.\n'
     prompt = '>'
@@ -13,30 +14,32 @@ class PolygonShell(cmd.Cmd):
     # ----- basic turtle commands -----
     def do_select(self, arg):
         'Move the turtle forward by the specified distance:  FORWARD 10'
-        data = ("**** polygon: query **** \n"
-                " ##  Below are the tables can be queried\n"
-                "        image,dataset,annotation,training_set,version\n"
-                " ##  Sql query :\n"
-                " ##      Example: \n"
-                "               1. select * from images\n"
-                "               2. select * from dataset limit 5\n"
-                "               3. select objectName from annotation\n"
-                " ##  No sql query : \n"
-                "        Example: \n"
-                "                 db.<table_name>.find({'<column_name>':'<value>'})\n"
-                "                 db.<table_name>.count({'<column_name>':'<value>'})")
-
-        if '|' in arg:
-            x=arg.split("|")
-            args=x[0]
-            outptDisplay =True
-        else:
-            args=arg
-            outptDisplay =False
-        query="select "+ str(args)
-        parsedData=parse.parse_sql(query)
-        sqlResult = rest_connect.sqlreslt(parsedData)
+        sqlResult=""
         try:
+            data = ("**** polygon: query **** \n"
+                    " ##  Below are the tables can be queried\n"
+                    "        image,dataset,annotation,training_set,version\n"
+                    " ##  Sql query :\n"
+                    " ##      Example: \n"
+                    "               1. select * from images\n"
+                    "               2. select * from dataset limit 5\n"
+                    "               3. select objectName from annotation\n"
+                    " ##  No sql query : \n"
+                    "        Example: \n"
+                    "                 db.<table_name>.find({'<column_name>':'<value>'})\n"
+                    "                 db.<table_name>.count({'<column_name>':'<value>'})")
+
+            if '|' in arg:
+                x=arg.split("|")
+                args=x[0]
+                outptDisplay =True
+            else:
+                args=arg
+                outptDisplay =False
+            query="select "+ str(args)
+            parsedData=parse.parse_sql(query)
+            sqlResult = rest_connect.sqlreslt(parsedData)
+
             error1 = sqlResult["error"]
             cnt = sqlResult["count"]
             res = sqlResult["results"]
@@ -60,34 +63,40 @@ class PolygonShell(cmd.Cmd):
                     "results": res,
                 }
                 print(json.dumps(x, indent=3))
-        except:
+
+
+        except Exception:
+            #traceback.print_exc()
+            print("You have an error in your query syntax")
             print(sqlResult)
             print('\033[92m' +data)
 
     def do_db(self, arg):
         'Move the turtle forward by the specified distance:  FORWARD 10'
-        data = ("**** polygon: query **** \n"
-                " ##  Below are the tables can be queried\n"
-                "        image,dataset,annotation,training_set,version\n"
-                " ##  Sql query :\n"
-                " ##      Example: \n"
-                "               1. select * from images\n"
-                "               2. select * from dataset limit 5\n"
-                "               3. select objectName from annotation\n"
-                " ##  No sql query : \n"
-                "        Example: \n"
-                "                 db.<table_name>.find({'<column_name>':'<value>'})\n"
-                "                 db.<table_name>.count({'<column_name>':'<value>'})")
-        if '|' in arg:
-            x = arg.split("|")
-            args = x[0]
-            outptDisplay = True
-        else:
-            args = arg
-            outptDisplay = False
-        pharse="db"+args
-        nosqlResult = rest_connect.nosqlreslt(pharse)
+        nosqlResult=""
         try:
+            data = ("**** polygon: query **** \n"
+                    " ##  Below are the tables can be queried\n"
+                    "        image,dataset,annotation,training_set,version\n"
+                    " ##  Sql query :\n"
+                    " ##      Example: \n"
+                    "               1. select * from images\n"
+                    "               2. select * from dataset limit 5\n"
+                    "               3. select objectName from annotation\n"
+                    " ##  No sql query : \n"
+                    "        Example: \n"
+                    "                 db.<table_name>.find({'<column_name>':'<value>'})\n"
+                    "                 db.<table_name>.count({'<column_name>':'<value>'})")
+            if '|' in arg:
+                x = arg.split("|")
+                args = x[0]
+                outptDisplay = True
+            else:
+                args = arg
+                outptDisplay = False
+            pharse="db"+args
+            nosqlResult = rest_connect.nosqlreslt(pharse)
+
             error1=nosqlResult["error"]
             cnt=nosqlResult["count"]
             res=nosqlResult["results"]
@@ -112,6 +121,7 @@ class PolygonShell(cmd.Cmd):
                 }
                 print(json.dumps(x, indent=3))
         except:
+            print("You have an error in your query syntax")
             print(nosqlResult)
             print('\033[92m' +data)
 
